mullvadapp

package
v0.0.0-...-aa8acd1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 23, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Server

type Server struct{}

A Server implements the ability to switch mullvad via app cli. It implements the Switchable and Indexable interfaces.

func New

func New() (*Server, error)

New creates a new Server to switch mullvad via app cli.

func (*Server) Current

func (s *Server) Current() (string, error)

Current returns the current relay. It can be a country location, or a country and city location, or the relay hostname.

func (*Server) Index

func (s *Server) Index(w io.Writer) error

Index writes an HTML index page to switch the Server.

func (*Server) List

func (s *Server) List() ([]string, error)

List lists available relay locations.

func (*Server) Switch

func (s *Server) Switch(location string) error

Switch switches to the specified location. Location: country (e.g. us), country city (e.g. us nyc) or hostname (e.g. us-nyc-wg-001).

Jump to