Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct{}
A Server implements the ability to switch mullvad via app cli. It implements the Switchable and Indexable interfaces.
func (*Server) Current ¶
Current returns the current relay. It can be a country location, or a country and city location, or the relay hostname.
Click to show internal directories.
Click to hide internal directories.